Re: [PATCH v2 08/11] staging: typec: tcpm: Set mux to device mode when configured as such

From: Hans de Goede
Date: Fri Sep 22 2017 - 10:02:43 EST


Hi,

On 09/11/2017 12:56 AM, Guenter Roeck wrote:
On 09/05/2017 09:42 AM, Hans de Goede wrote:
Setting the mux to TYPEC_MUX_NONE, TCPC_USB_SWITCH_DISCONNECT when the
data-role is device is not correct. Plenty of devices support operating
as USB device through a (separate) USB device controller.

So this commit instead splits out TYPEC_MUX_USB into TYPEC_MUX_USB_HOST
and TYPEC_MUX_USB_DEVICE and makes tcpm_set_roles() set the mux
accordingly.

Likewise TCPC_MUX_DP gets renamed to TCPC_MUX_DP_SRC to make clear that
this is for configuring the Type-C port as a Display Port source, not a
sink.

Last this commit makes tcpm_reset_port() to set the mux to
TYPEC_MUX_NONE, TCPC_USB_SWITCH_DISCONNECT so that it does not and up
staying in host (and with this commit also device) mode after a detach.

This sentence is hard to understand.

Ok, changed to:

"Last this commit makes tcpm_reset_port() call tcpm_mux_set(port,
TYPEC_MUX_NONE, TCPC_USB_SWITCH_DISCONNECT) so that the mux does _not_
stay in its last mode after a detach."

For v3 of this patchset.


Signed-off-by: Hans de Goede <hdegoede@xxxxxxxxxx>

Otherwise

Reviewed-by: Guenter Roeck <linux@xxxxxxxxxxxx>

And added your Reviewed-by.

Thanks & Regards,

Hans






---
 drivers/staging/typec/tcpm.c | 7 ++++---
 drivers/staging/typec/tcpm.h | 22 ++++++++++++++--------
 2 files changed, 18 insertions(+), 11 deletions(-)

diff --git a/drivers/staging/typec/tcpm.c b/drivers/staging/typec/tcpm.c
index 8af62e74d54c..ffe7e26d4ed3 100644
--- a/drivers/staging/typec/tcpm.c
+++ b/drivers/staging/typec/tcpm.c
@@ -752,11 +752,11 @@ static int tcpm_set_roles(struct tcpm_port *port, bool attached,
ÂÂÂÂÂ int ret;
ÂÂÂÂÂ if (data == TYPEC_HOST)
-ÂÂÂÂÂÂÂ ret = tcpm_mux_set(port, TYPEC_MUX_USB,
+ÂÂÂÂÂÂÂ ret = tcpm_mux_set(port, TYPEC_MUX_USB_HOST,
ÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂ TCPC_USB_SWITCH_CONNECT);
ÂÂÂÂÂ else
-ÂÂÂÂÂÂÂ ret = tcpm_mux_set(port, TYPEC_MUX_NONE,
-ÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂ TCPC_USB_SWITCH_DISCONNECT);
+ÂÂÂÂÂÂÂ ret = tcpm_mux_set(port, TYPEC_MUX_USB_DEVICE,
+ÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂ TCPC_USB_SWITCH_CONNECT);
ÂÂÂÂÂ if (ret < 0)
ÂÂÂÂÂÂÂÂÂ return ret;
@@ -2025,6 +2025,7 @@ static void tcpm_reset_port(struct tcpm_port *port)
ÂÂÂÂÂ tcpm_init_vconn(port);
ÂÂÂÂÂ tcpm_set_current_limit(port, 0, 0);
ÂÂÂÂÂ tcpm_set_polarity(port, TYPEC_POLARITY_CC1);
+ÂÂÂ tcpm_mux_set(port, TYPEC_MUX_NONE, TCPC_USB_SWITCH_DISCONNECT);
ÂÂÂÂÂ tcpm_set_attached_state(port, false);
ÂÂÂÂÂ port->try_src_count = 0;
ÂÂÂÂÂ port->try_snk_count = 0;
diff --git a/drivers/staging/typec/tcpm.h b/drivers/staging/typec/tcpm.h
index 7e9a6b7b5cd6..f662eed48c86 100644
--- a/drivers/staging/typec/tcpm.h
+++ b/drivers/staging/typec/tcpm.h
@@ -83,17 +83,23 @@ enum tcpc_usb_switch {
 };
 /* Mux state attributes */
-#define TCPC_MUX_USB_ENABLEDÂÂÂÂÂÂÂ BIT(0)ÂÂÂ /* USB enabled */
-#define TCPC_MUX_DP_ENABLEDÂÂÂÂÂÂÂ BIT(1)ÂÂÂ /* DP enabled */
-#define TCPC_MUX_POLARITY_INVERTEDÂÂÂ BIT(2)ÂÂÂ /* Polarity inverted */
+#define TCPC_MUX_USB_DEVICE_ENABLEDÂÂÂÂÂÂÂ BIT(0)ÂÂÂ /* USB device enabled */
+#define TCPC_MUX_USB_HOST_ENABLEDÂÂÂÂÂÂÂ BIT(1)ÂÂÂ /* USB host enabled */
+#define TCPC_MUX_DP_SRC_ENABLEDÂÂÂÂÂÂÂÂÂÂÂ BIT(2)ÂÂÂ /* DP enabled */
+#define TCPC_MUX_POLARITY_INVERTEDÂÂÂÂÂÂÂ BIT(3)ÂÂÂ /* Polarity inverted */
 /* Mux modes, decoded to attributes */
 enum tcpc_mux_mode {
-ÂÂÂ TYPEC_MUX_NONEÂÂÂ = 0,ÂÂÂÂÂÂÂÂÂÂÂÂÂÂÂ /* Open switch */
-ÂÂÂ TYPEC_MUX_USBÂÂÂ = TCPC_MUX_USB_ENABLED,ÂÂÂÂÂÂÂ /* USB only */
-ÂÂÂ TYPEC_MUX_DPÂÂÂ = TCPC_MUX_DP_ENABLED,ÂÂÂÂÂÂÂ /* DP only */
-ÂÂÂ TYPEC_MUX_DOCKÂÂÂ = TCPC_MUX_USB_ENABLED |ÂÂÂ /* Both USB and DP */
-ÂÂÂÂÂÂÂÂÂÂÂÂÂ TCPC_MUX_DP_ENABLED,
+ÂÂÂ /* Open switch */
+ÂÂÂ TYPEC_MUX_NONE = 0,
+ÂÂÂ /* USB device only */
+ÂÂÂ TYPEC_MUX_USB_DEVICE = TCPC_MUX_USB_DEVICE_ENABLED,
+ÂÂÂ /* USB host only */
+ÂÂÂ TYPEC_MUX_USB_HOST = TCPC_MUX_USB_HOST_ENABLED,
+ÂÂÂ /* DP source only */
+ÂÂÂ TYPEC_MUX_DP = TCPC_MUX_DP_SRC_ENABLED,
+ÂÂÂ /* Both USB host and DP source */
+ÂÂÂ TYPEC_MUX_DOCK = TCPC_MUX_USB_HOST_ENABLED | TCPC_MUX_DP_SRC_ENABLED,
 };
 struct tcpc_mux_dev {